@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.6.0"
+    version = "1.6.1"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -120,7 +120,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"{payload} > 查看详情: <font color=blue>[{group.title if group.title else 'unknown'}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
         payload = f"{payload} > 全部报错: {group} \n\n"
-        payload = f"{payload} > 全部报错: {group.Group} \n\n"
+        payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
 
         headers = {
             "Content-type": "application/json",
